/*
   uskvb.h: SmartDongle API Library v3.2 for Visual Basic 6
   with mutex protected functions.


   www.smartdongle.com

   MicroWorks, Inc.
   2808 North Cole Road
   Boise, ID 83704
*/

#ifndef _DEFINED_BE898DD9_4D65_4b12_AC6D_0F0C0EA81D75
#define _DEFINED_BE898DD9_4D65_4b12_AC6D_0F0C0EA81D75

#ifndef _WINDOWS_
   #include <Windows.h>
#endif

/*
   Three on-chip SmartDongle encrpytion modes to choose from.
   This provide protection for SmartDongle on-board memory only.
   Select QTS_OPTION_CRYPT_IO to encrypt data written to SmartDongle
   user memory.
*/
#define QTS_OPTION_ON_CHIP_EPROM_PROTECT_STRONG   0x00
#define QTS_OPTION_ON_CHIP_EPROM_PROTECT_DISABLE  0x01
#define QTS_OPTION_ON_CHIP_EPROM_PROTECT_FAST     0x02

/*
   Maximum string length returned from GetErrorString()
*/
#define QTS_ERROR_STRING_LENGTH_MAX 128

/*
   Maximum string length returned from GetErrorString()
*/
#define QTS_ERROR_STRING_LENGTH_MAX 128

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/* Same structure as Shell DLLVersionInfo in shlwapi.h */
typedef struct _USKDllVersionInfo
{
   DWORD cbSize;
   DWORD dwMajorVersion;                   /* Major version */
   DWORD dwMinorVersion;                   /* Minor version */
   DWORD dwBuildNumber;                    /* Build number */
   DWORD dwPlatformID;                     /* DLLVER_PLATFORM_* */
} USKDLLVERSIONINFO;

/* Platform IDs for DLLVERSIONINFO */
#define EXPORT_DLL_FUNCTIONVER_PLATFORM_WINDOWS         0x00000001      /* Windows 95 */
#define EXPORT_DLL_FUNCTIONVER_PLATFORM_NT              0x00000002      /* Windows NT */

   #ifndef EXPORT_DLL_FUNCTION
   /*
      Cause following DLL functions as to be defined as imports, unless
      DLL.h has overridden this behavior.
   */
      #define EXPORT_DLL_FUNCTION(type) type __stdcall
   #endif

   EXPORT_DLL_FUNCTION(int) SmartDongleInitGlobalMutex(void);
   EXPORT_DLL_FUNCTION(BOOL) SmartDongleCloseGlobalMutex(void);

   /* Get the usk.dll's version. */
   EXPORT_DLL_FUNCTION(int) DllGetVersion(USKDLLVERSIONINFO *pdvi);

/*
   Given the correct keys, P1 and P2, will place the dongle into
   the enabled state and read EEPROM into buffer.

   Valid address is 0 to 32431

   Note: Refer to sd_uskerr.h for returned errors.
*/
   EXPORT_DLL_FUNCTION(int) VBRead(
      char *sP1,
      char *sP2,
      int address,
      char *buffer,
      int size);

/*
   Given the correct keys, P1 and P2, will place the dongle into
   the enabled state and buffer into EEPROM.

   Valid address is 0 to 32431

   Note: Refer to sd_uskerr.h for returned errors.
*/
   EXPORT_DLL_FUNCTION(int) VBWrite(
      char *sP1,
      char *sP2,
      int address,
      char *buffer,
      int size);

/*
   SmartDongle reboot.
*/
   EXPORT_DLL_FUNCTION(int) Reset(void);

/*
   LED Control.
*/
   EXPORT_DLL_FUNCTION(int) LedGreen(void);
   EXPORT_DLL_FUNCTION(int) LedRed(void);
   EXPORT_DLL_FUNCTION(int) LedOff(void);

/*
   User EPROM memory encryption control - Firmware >=v1.42

   Modes:

   0 - User EPROM memory space protected by strong (AES) encryption
   1 - User EPROM memory space is unencrypted
   2 - User EPROM memory space protected by fast encryption
*/
   EXPORT_DLL_FUNCTION(int) VBWriteCryptMode(
      char *sP1,
      char *sP2,
      char mode);

/*
   Read current encryption mode.
*/
   EXPORT_DLL_FUNCTION(int) ReadCryptMode(char *mode);

/*
   Attempt to locate correct SmartDongle by iterating through the device list,
   returning serial number in sn, if sn is non-NULL.
   User must allocate CP2_SERIALNUM_LENGTH+1 for returned serial number string.
*/
   EXPORT_DLL_FUNCTION(int)VBGetEpromSize(
      char *sP1,
      char *sP2);

/*
   User must allocate CP2_SERIALNUM_LENGTH+1 sn buffer
*/
   EXPORT_DLL_FUNCTION(int) GetSerialNumber(char *sn);

/*
   For SmartDongle >=v1.50 using >= v2.3 driver only.
   This will configure the SmartDongle for use with
   the 2.3 driver only.

   Caution: This configuration is permanent. SmartDongle
            must be sent back to the manufacturer to be
            reset to use the older drivers (<= v2.2.0).
*/
   EXPORT_DLL_FUNCTION(int) SetStrict(void);

/*
   Return error description string corresponding to error code.
   User must allocate string size of QTS_ERROR_STRING_LENGTH_MAX
*/
EXPORT_DLL_FUNCTION(void) GetErrorString(char *errorString, int error);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif /* _DEFINED_BE898DD9_4D65_4b12_AC6D_0F0C0EA81D75 */
